# bodoTK

**bodoTK** is a Python library designed for tokenization of the Bodo language. This library provides functions to perform sentence-level, word-level, and character-level tokenization.

## Features

- Sentence-level tokenization
- Word-level tokenization
- Character-level tokenization

## Installation

You can install `bodoTK` using `pip`. To install it locally, use the following command:

```bash
pip install /path/to/your/package/bodoTK-0.1-py3-none-any.whl

